@@ -53,7 +53,7 @@ class ParamikoServer(paramiko.ServerInterface):
 
 
 class Handler(BaseRequestHandler, Protocol):
-    message_terminator = b"\n"
+    message_terminators = [b"\n"]
     default_port = 22
 
     def handle(self):
@@ -65,6 +65,7 @@ class Handler(BaseRequestHandler, Protocol):
         t.start_server(server=ParamikoServer())
         self.channel = t.accept()
         self.open_upstream()
+        self.handle_prompt()
         while not stopped:
             request, request_id = self.read_request()
             self.handle_request(request, request_id)
@@ -97,13 +98,20 @@ class Handler(BaseRequestHandler, Protocol):
         transport: paramiko.Transport = client._transport
         self.upstream_channel = transport.open_session()
 
+    def handle_prompt(self):
+        self.handle_request({"command": ""}, "")
+
     def read_proxy_response(self):
         return {"response": self.read_message(self.upstream_channel).decode()}
 
     def read_message(self, channel):
         message = b""
-        while self.message_terminator not in message and not stopped:
+        end_of_message = False
+        while not end_of_message and not stopped:
             message += channel.recv(1024)
+            for terminator in self.message_terminators:
+                if terminator in message:
+                    end_of_message = True
         return message
 
 
